Poker Cards
===========

Python modules for working with poker cards and managing games.

Locations
---------

Poker Cards packages are available from Cheese shop (PyPI)
at https://pypi.python.org/pypi/pokercards

The `project page <https://github.com/beli-sk/pokercards>`_ is hosted on Github.

If you've never worked with *git* or contributed to a project on Github,
there is a `quick start guide <https://help.github.com/articles/fork-a-repo>`_.

If you find something wrong or know of a missing feature, please
`create an issue <https://github.com/beli-sk/pokercards/issues>`_ on the project
page. If you find that inconvenient or have some security concerns, you could
also drop me a line at <devel@beli.sk>.

How to use
----------

Install
~~~~~~~

::

    pip install pokercards

License
-------

Copyright 2013 Michal Belica <devel@beli.sk>

::

    Poker Cards is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
    
    Poker Cards is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
    along with Poker Cards.  If not, see < http://www.gnu.org/licenses/ >.


